==> ZenTaoPMS.16.5.php7.2_7.4.zip: zentaopms/extension/biz/feedback/lang/fr.php <==
<?php
$lang->feedback->common            = 'Feedback';
$lang->feedback->module            = 'Module';
$lang->feedback->moduleAB          = 'Module';
$lang->feedback->manageCate        = 'G?rer Cat?gories';
$lang->feedback->index             = 'Accueil Feedback';
$lang->feedback->create            = 'Ajout Feedback';
$lang->feedback->edit              = 'Editer Feedback';
$lang->feedback->createFaq         = 'Ajout FAQ';
$lang->feedback->faq               = 'FAQ';
$lang->feedback->nonRDBrowse       = 'Interface Feedback';
$lang->feedback->browse            = 'Liste Feedback';
$lang->feedback->list              = 'Feedback';
$lang->feedback->header            = 'Feedback';
$lang->feedback->view              = 'D?tail Feedback';
$lang->feedback->review            = 'Examen';
$lang->feedback->reviewAction      = 'Examiner Feedback';
$lang->feedback->adminView         = 'Interface D?veloppement';
$lang->feedback->close             = 'Fermer';
$lang->feedback->closeAction       = 'Fermer Feedback';
$lang->feedback->feelLike          = " J'aime!";
$lang->feedback->ask               = 'Doute';
$lang->feedback->toStory           = 'vers ' . $lang->SRCommon;
$lang->feedback->toTask            = 'vers T?che';
$lang->feedback->toBug             = 'vers Bug';
$lang->feedback->toTodo            = 'vers Agenda';
$lang->feedback->story             = $lang->SRCommon;
$lang->feedback->bug               = 'Bug';
$lang->feedback->todo              = 'Agenda';
$lang->feedback->task              = 'T?che';
$lang->feedback->reply             = 'R?pondre';
$lang->feedback->replyAction       = 'R?pondre au Feedback';
$lang->feedback->convert           = 'Convertir';
$lang->feedback->assign            = 'Assigner';
$lang->feedback->assignAction      = 'Assigner Feedback';
$lang->feedback->export            = 'Exporter';
$lang->feedback->exportAction      = 'Exporter Feedback';
$lang->feedback->assignTo          = 'Assign';
$lang->feedback->mailto            = 'Mailto';
$lang->feedback->delete            = 'Supprimer Feedback';
$lang->feedback->mailNotify        = 'Notification par mail';
$lang->feedback->search            = 'Recherche';
$lang->feedback->comment           = 'Commenter';
$lang->feedback->products          = 'Privil?ge';
$lang->feedback->batchEdit         = 'Editer par lot';
$lang->feedback->batchClose        = 'Fermer par lot';
$lang->feedback->batchReview       = 'Examen par lot';
$lang->feedback->batchAssignTo     = 'Assigner par lot';
$lang->feedback->batchChangeModule = 'R?affecter Modules par lot';
$lang->feedback->manageProduct     = 'G?rer les Privil?ges Utilisateur';
$lang->feedback->consumed          = 'Coût Total';

$lang->feedback->id             = 'ID';
$lang->feedback->product        = $lang->productCommon;
$lang->feedback->title          = 'Titre';
$lang->feedback->type           = 'Type';
$lang->feedback->desc           = 'Description';
$lang->feedback->status         = 'Statut';
$lang->feedback->subStatus      = 'Sous-Statut';
$lang->feedback->openedBy       = 'Ajout? par';
$lang->feedback->openedDate     = 'Ajout? le';
$lang->feedback->processedBy    = 'R?pondu par';
$lang->feedback->processedDate  = 'R?pondu le';
$lang->feedback->reviewedBy     = 'Examin? par';
$lang->feedback->reviewedDate   = 'Examin? le';
$lang->feedback->reviewResult   = 'Verdict';
$lang->feedback->reviewedByAB   = 'Examinateur';
$lang->feedback->reviewedDateAB = 'Date';
$lang->feedback->reviewResultAB = 'Verdict';
$lang->feedback->assignedTo     = 'Assign';
$lang->feedback->assignedDate   = 'Date Assign.';
$lang->feedback->closedBy       = 'Ferm? par';
$lang->feedback->closedDate     = 'Date Fermeture';
$lang->feedback->closedReason   = 'Raison Fermeture';
$lang->feedback->public         = 'Public';
$lang->feedback->notify         = 'Notification';
$lang->feedback->likes          = 'Likes';
$lang->feedback->result         = 'R?sultat';
$lang->feedback->files          = 'Fichiers';
$lang->feedback->labelBasic     = 'Basic';
$lang->feedback->dept           = 'Compartiment';
$lang->feedback->editedBy       = 'Modifi? par';
$lang->feedback->editedDate     = 'Dern.Modif';
$lang->feedback->contactInfo    = 'Contact';
$lang->feedback->noAssigned     = 'Non assign';
$lang->feedback->deptManager    = 'Responsable';
$lang->feedback->reviewOpinion  = 'Opinion examen';
$lang->feedback->deleted        = 'Supprim';
$lang->feedback->execution      = 'Select sprint/stage';

$lang->feedback->lblBasic       = 'Info de Base';
$lang->feedback->lblTrace       = 'Diagramme de Tra?abilit';
$lang->feedback->assigntome     = "Me l'assigner";
$lang->feedback->allProduct     = 'Tout ' . $lang->productCommon;
$lang->feedback->nextStep       = 'Next';
$lang->feedback->selectProjects = 'Select Projects';

$lang->feedback->grantUser   = 'Utilisateur autoris';
$lang->feedback->noGrantUser = 'Utilisateur non autoris';
$lang->feedback->hasPrivUser = 'Les utilisateurs de Feedback ont les privil?ges de tous les produits par d?faut. Si un privil?ge est attribu?, ils auront les privil?ges du produit associ?.';

$lang->feedback->tabList['unclosed'] = 'Ouverts';
$lang->feedback->tabList['all']      = 'Tout';
$lang->feedback->tabList['public']   = 'Public';

$lang->feedback->typeList[''] = '';
$lang->feedback->typeList['story']       = 'Story';
$lang->feedback->typeList['task']        = 'Task';
$lang->feedback->typeList['bug']         = 'Bug';
$lang->feedback->typeList['todo']        = 'Todo';
$lang->feedback->typeList['advice']      = 'Advice';
$lang->feedback->typeList['issue']       = 'Issue';
$lang->feedback->typeList['risk']        = 'Risk';
$lang->feedback->typeList['opportunity'] = 'Opportunity';

$lang->feedback->reviewResultList['']        = '';
$lang->feedback->reviewResultList['pass']    = 'Pass';
$lang->feedback->reviewResultList['clarify'] = '? clarifier';

$lang->feedback->statusList['']           = '';
$lang->feedback->statusList['noreview']   = 'Attente examen';
$lang->feedback->statusList['clarify']    = '? clarifier';
$lang->feedback->statusList['wait']       = 'En attente';
$lang->feedback->statusList['commenting'] = 'En cours';
$lang->feedback->statusList['replied']    = 'R?pondu';
$lang->feedback->statusList['asked']      = 'Incertain';
$lang->feedback->statusList['tobug']      = 'Convertir en Bug';
$lang->feedback->statusList['tostory']    = 'Convertir en ' . $lang->SRCommon;
$lang->feedback->statusList['totask']     = 'Convertir en T?che';
$lang->feedback->statusList['totodo']     = 'Convertir en Agenda';
$lang->feedback->statusList['closed']     = 'Ferm';

$lang->feedback->closedReasonList[]            = '';
$lang->feedback->closedReasonList['commented'] = 'R?pondu';
$lang->feedback->closedReasonList['repeat']    = 'R?p?ter';
$lang->feedback->closedReasonList['refuse']    = 'Rejeter';

$lang->feedback->solutionList['']        = '';
$lang->feedback->solutionList['tobug']   = 'Convert to Bug';
$lang->feedback->solutionList['tostory'] = 'Convert to ' . $lang->SRCommon;
$lang->feedback->solutionList['totask']  = 'Convert to task';
$lang->feedback->solutionList['totodo']  = 'Convert to Todo';

$lang->feedback->publicList['']  = '';
$lang->feedback->publicList['0'] = 'Priv';
$lang->feedback->publicList['1'] = 'Public';

$lang->feedback->confirmDelete = 'Voulez-vous supprimer ce feedback ?';
$lang->feedback->confirmClose  = 'Voulez-vous cl?turer ce feedback ?';
$lang->feedback->noProject     = 'Haven’t chosen a project yet';

$lang->feedback->commented        = '$date, r?pondu par <strong>$actor</strong>.' . "\n";
$lang->feedback->noModule         = "<div>Vous n'avez pas de cat?gories.</div>";
$lang->feedback->mustChooseResult = 'S?lect Verdict';

$lang->feedback->action = new stdclass();
$lang->feedback->action->closed   = array('main' => '$date, ferm? par <strong>$actor</strong>. Raison de fermeture est <strong>$extra</strong>.', 'extra' => 'closedReasonList');
$lang->feedback->action->reviewed = array('main' => '$date, examin? par <strong>$actor</strong>. Le verdict est <strong>$extra</strong>.', 'extra' => 'reviewResultList');

==> ZenTaoPMS.17.2.php7.1.zip: zentaopms/extension/biz/feedback/lang/fr.php <==
<?php
global $config;
$lang->feedback->common            = 'Feedback';
$lang->feedback->module            = 'Module';
$lang->feedback->moduleAB          = 'Module';
$lang->feedback->allModule         = 'All Module';
$lang->feedback->manageCate        = 'G?rer Cat?gories';
$lang->feedback->index             = 'Accueil Feedback';
$lang->feedback->create            = 'Ajout Feedback';
$lang->feedback->edit              = 'Editer Feedback';
$lang->feedback->createFaq         = 'Ajout FAQ';
$lang->feedback->faq               = 'FAQ';
$lang->feedback->nonRDBrowse       = 'Interface Feedback';
$lang->feedback->browse            = 'Liste Feedback';
$lang->feedback->list              = 'Feedback';
$lang->feedback->header            = 'Feedback';
$lang->feedback->view              = 'D?tail Feedback';
$lang->feedback->review            = 'Examen';
$lang->feedback->reviewAction      = 'Examiner Feedback';
$lang->feedback->adminView         = 'Interface D?veloppement';
$lang->feedback->admin             = 'Developer Feedback List';
$lang->feedback->close             = 'Fermer';
$lang->feedback->closeAction       = 'Fermer Feedback';
$lang->feedback->feelLike          = " J'aime!";
$lang->feedback->ask               = 'Doute';
$lang->feedback->toStory           = 'vers ' . $lang->SRCommon;
$lang->feedback->toTask            = 'vers T?che';
$lang->feedback->toBug             = 'vers Bug';
$lang->feedback->toTodo            = 'vers Agenda';
$lang->feedback->story             = $lang->SRCommon;
$lang->feedback->bug               = 'Bug';
$lang->feedback->todo              = 'Agenda';
$lang->feedback->task              = 'T?che';
$lang->feedback->reply             = 'R?pondre';
$lang->feedback->replyAction       = 'R?pondre au Feedback';
$lang->feedback->convert           = 'Convertir';
$lang->feedback->assign            = 'Assigner';
$lang->feedback->assignAction      = 'Assigner Feedback';
$lang->feedback->export            = 'Exporter';
$lang->feedback->exportAction      = 'Exporter Feedback';
$lang->feedback->assignTo          = 'Assign';
$lang->feedback->mailto            = 'Mailto';
$lang->feedback->delete            = 'Supprimer Feedback';
$lang->feedback->mailNotify        = 'Notification par mail';
$lang->feedback->search            = 'Recherche';
$lang->feedback->comment           = 'Commenter';
$lang->feedback->products          = 'Privil?ge';
$lang->feedback->batchEdit         = 'Editer par lot';
$lang->feedback->batchClose        = 'Fermer par lot';
$lang->feedback->batchReview       = 'Examen par lot';
$lang->feedback->batchAssignTo     = 'Assigner par lot';
$lang->feedback->batchChangeModule = 'R?affecter Modules par lot';
$lang->feedback->manageProduct     = 'G?rer les Privil?ges Utilisateur';
$lang->feedback->consumed          = 'Coût Total';

$lang->feedback->id             = 'ID';
$lang->feedback->product        = $lang->productCommon;
$lang->feedback->title          = 'Titre';
$lang->feedback->type           = 'Type';
$lang->feedback->solution       = 'Treatment Plan';
$lang->feedback->desc           = 'Description';
$lang->feedback->status         = 'Statut';
$lang->feedback->subStatus      = 'Sous-Statut';
$lang->feedback->openedBy       = 'Ajout? par';
$lang->feedback->openedDate     = 'Ajout? le';
$lang->feedback->processedBy    = 'R?pondu par';
$lang->feedback->processedDate  = 'R?pondu le';
$lang->feedback->reviewedBy     = 'Examin? par';
$lang->feedback->reviewedDate   = 'Examin? le';
$lang->feedback->reviewResult   = 'Verdict';
$lang->feedback->reviewedByAB   = 'Examinateur';
$lang->feedback->reviewedDateAB = 'Date';
$lang->feedback->reviewResultAB = 'Verdict';
$lang->feedback->assignedTo     = 'Assign';
$lang->feedback->assignedDate   = 'Date Assign.';
$lang->feedback->closedBy       = 'Ferm? par';
$lang->feedback->closedDate     = 'Date Fermeture';
$lang->feedback->closedReason   = 'Raison Fermeture';
$lang->feedback->public         = 'Public';
$lang->feedback->publicAB       = 'Public';
$lang->feedback->notify         = 'Notification';
$lang->feedback->notifyEmail    = 'Notification Email';
$lang->feedback->feedbackBy     = 'Feedback';
$lang->feedback->likes          = 'Likes';
$lang->feedback->result         = 'R?sultat';
$lang->feedback->files          = 'Fichiers';
$lang->feedback->labelBasic     = 'Basic';
$lang->feedback->dept           = 'Compartiment';
$lang->feedback->editedBy       = 'Modifi? par';
$lang->feedback->editedDate     = 'Dern.Modif';
$lang->feedback->contactInfo    = 'Contact';
$lang->feedback->noAssigned     = 'Non assign';
$lang->feedback->deptManager    = 'Responsable';
$lang->feedback->reviewOpinion  = 'Opinion examen';
$lang->feedback->deleted        = 'Supprim';
$lang->feedback->project        = 'Select project';
$lang->feedback->execution      = 'Select sprint/stage';

$lang->feedback->lblBasic       = 'Info de Base';
$lang->feedback->lblTrace       = 'Diagramme de Tra?abilit';
$lang->feedback->assigntome     = "Me l'assigner";
$lang->feedback->allProduct     = 'Tout ' . $lang->productCommon;
$lang->feedback->nextStep       = 'Next';
$lang->feedback->selectProjects = 'Select Projects';

$lang->feedback->grantUser   = 'Utilisateur autoris';
$lang->feedback->noGrantUser = 'Utilisateur non autoris';
$lang->feedback->hasPrivUser = 'Les utilisateurs de Feedback ont les privil?ges de tous les produits par d?faut. Si un privil?ge est attribu?, ils auront les privil?ges du produit associ?.';

$lang->feedback->tabList['unclosed'] = 'Ouverts';
$lang->feedback->tabList['all']      = 'Tout';
$lang->feedback->tabList['public']   = 'Public';

$lang->feedback->typeList[''] = '';
$lang->feedback->typeList['story']       = 'Story';
$lang->feedback->typeList['task']        = 'Task';
$lang->feedback->typeList['bug']         = 'Bug';
$lang->feedback->typeList['todo']        = 'Todo';
$lang->feedback->typeList['advice']      = 'Advice';
if($this->config->systemMode == 'new')
{
    $lang->feedback->typeList['issue']       = 'Issue';
    $lang->feedback->typeList['risk']        = 'Risk';
    $lang->feedback->typeList['opportunity'] = 'Opportunity';
}

$lang->feedback->reviewResultList['']        = '';
$lang->feedback->reviewResultList['pass']    = 'Pass';
$lang->feedback->reviewResultList['clarify'] = '? clarifier';

$lang->feedback->statusList['']           = '';
$lang->feedback->statusList['noreview']   = 'Attente examen';
$lang->feedback->statusList['clarify']    = '? clarifier';
$lang->feedback->statusList['wait']       = 'En attente';
$lang->feedback->statusList['commenting'] = 'En cours';
$lang->feedback->statusList['replied']    = 'R?pondu';
$lang->feedback->statusList['asked']      = 'Incertain';
$lang->feedback->statusList['tobug']      = 'Convertir en Bug';
$lang->feedback->statusList['tostory']    = 'Convertir en ' . $lang->SRCommon;
$lang->feedback->statusList['totask']     = 'Convertir en T?che';
$lang->feedback->statusList['totodo']     = 'Convertir en Agenda';
$lang->feedback->statusList['closed']     = 'Ferm';

$lang->feedback->closedReasonList[]          = '';
$lang->feedback->closedReasonList['commented'] = 'R?pondu';
$lang->feedback->closedReasonList['repeat']    = 'R?p?ter';
$lang->feedback->closedReasonList['refuse']    = 'Rejeter';

$lang->feedback->solutionList['']        = '';
$lang->feedback->solutionList['tobug']   = 'Convert to Bug';
$lang->feedback->solutionList['tostory'] = 'Convert to ' . $lang->SRCommon;
$lang->feedback->solutionList['totask']  = 'Convert to task';
$lang->feedback->solutionList['totodo']  = 'Convert to Todo';

$lang->feedback->publicList['']  = '';
$lang->feedback->publicList['0'] = 'Priv';
$lang->feedback->publicList['1'] = 'Public';

$lang->feedback->confirmDelete = 'Voulez-vous supprimer ce feedback ?';
$lang->feedback->confirmClose  = 'Voulez-vous cl?turer ce feedback ?';
$lang->feedback->noProject     = 'Haven’t chosen a project yet';
$lang->feedback->noExecution   = 'Haven’t chosen a execution yet';

$lang->feedback->commented        = '$date, r?pondu par <strong>$actor</strong>.' . "\n";
$lang->feedback->noModule         = "<div>Vous n'avez pas de cat?gories.</div>";
$lang->feedback->mustChooseResult = 'S?lect Verdict';
$lang->feedback->mustInputComment = 'Reply content must be filled in';
$lang->feedback->batchEditTip     = 'Feedback with ID %s is not created by the user and will be ignored automatically';

$lang->feedback->action = new stdclass();
$lang->feedback->action->closed   = array('main' => '$date, ferm? par <strong>$actor</strong>. Raison de fermeture est <strong>$extra</strong>.', 'extra' => 'closedReasonList');
$lang->feedback->action->reviewed = array('main' => '$date, examin? par <strong>$actor</strong>. Le verdict est <strong>$extra</strong>.', 'extra' => 'reviewResultList');

$lang->feedback->featurebar = new stdclass();
$lang->feedback->featurebar->unclosed   = 'Unclosed|feedback|admin|browseType=unclosed';
$lang->feedback->featurebar->all        = 'All|feedback|admin|browseType=all';
$lang->feedback->featurebar->public     = 'Public|feedback|admin|browseType=public';
$lang->feedback->featurebar->tostory    = "To {$lang->SRCommon}|feedback|admin|browseType=tostory";
$lang->feedback->featurebar->totask     = 'To Task|feedback|admin|browseType=totask';
$lang->feedback->featurebar->tobug      = 'To Bug|feedback|admin|browseType=tobug';
$lang->feedback->featurebar->totodo     = 'To Todo|feedback|admin|browseType=totodo';
$lang->feedback->featurebar->review     = 'Review|feedback|admin|browseType=review';
$lang->feedback->featurebar->assigntome = 'AssignedToMe|feedback|admin|browseType=assigntome';
